==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/GridFilterDialogViewModelGroupingDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridFilterDialogViewModelGroupingDescription } from "./GridFilterDialogViewModelGroupingDescription";
/**
 * @hidden
 */
export let GridFilterDialogViewModelGroupingDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridFilterDialogViewModelGroupingDescriptionMetadata extends Base {
        static b(a) {
            if (GridFilterDialogViewModelGroupingDescriptionMetadata.a == null) {
                GridFilterDialogViewModelGroupingDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridFilterDialogViewModelGroupingDescriptionMetadata.c(GridFilterDialogViewModelGroupingDescriptionMetadata.a);
            }
            if (a.j(GridFilterDialogViewModelGroupingDescriptionMetadata.a)) {
                return;
            }
            a.y(GridFilterDialogViewModelGroupingDescriptionMetadata.a);
        }
        static c(a) {
            a.item("StartIndex", "Number:int");
            a.item("EndIndex", "Number:int");
            a.item("IsOrGrouping", "Boolean");
        }
        static d(a) {
            GridFilterDialogViewModelGroupingDescriptionMetadata.b(a);
            a.aa("GridFilterDialogViewModelGrouping", () => new GridFilterDialogViewModelGroupingDescription());
            a.z("GridFilterDialogViewModelGrouping", GridFilterDialogViewModelGroupingDescriptionMetadata.a);
        }
    }
    GridFilterDialogViewModelGroupingDescriptionMetadata.$t = /*@__PURE__*/ markType(GridFilterDialogViewModelGroupingDescriptionMetadata, 'GridFilterDialogViewModelGroupingDescriptionMetadata');
    GridFilterDialogViewModelGroupingDescriptionMetadata.a = null;
    return GridFilterDialogViewModelGroupingDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GridFilterDialogViewModelGroupingDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridFilterDialogViewModelGroupingDescription } from "./GridFilterDialogViewModelGroupingDescription";
/**
 * @hidden
 */
export let GridFilterDialogViewModelGroupingDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridFilterDialogViewModelGroupingDescriptionMetadata extends Base {
        static b(a) {
            if (GridFilterDialogViewModelGroupingDescriptionMetadata.a == null) {
                GridFilterDialogViewModelGroupingDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridFilterDialogViewModelGroupingDescriptionMetadata.c(GridFilterDialogViewModelGroupingDescriptionMetadata.a);
            }
            if (a.k(GridFilterDialogViewModelGroupingDescriptionMetadata.a)) {
                return;
            }
            a.aa(GridFilterDialogViewModelGroupingDescriptionMetadata.a);
        }
        static c(a) {
            a.item("StartIndex", "Number:int");
            a.item("EndIndex", "Number:int");
            a.item("IsOrGrouping", "Boolean");
        }
        static d(a) {
            GridFilterDialogViewModelGroupingDescriptionMetadata.b(a);
            a.ac("GridFilterDialogViewModelGrouping", () => new GridFilterDialogViewModelGroupingDescription());
            a.ab("GridFilterDialogViewModelGrouping", GridFilterDialogViewModelGroupingDescriptionMetadata.a);
        }
    }
    GridFilterDialogViewModelGroupingDescriptionMetadata.$t = /*@__PURE__*/ markType(GridFilterDialogViewModelGroupingDescriptionMetadata, 'GridFilterDialogViewModelGroupingDescriptionMetadata');
    GridFilterDialogViewModelGroupingDescriptionMetadata.a = null;
    return GridFilterDialogViewModelGroupingDescriptionMetadata;
})();
